==> flutter_conscent_plugin-0.1.8.tar.gz: lib/BulletsFormat.dart <==
// ignore_for_file: file_names

import 'package:flutter/material.dart';

void main() => runApp(const MyApp());

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return const MaterialApp(
      debugShowCheckedModeBanner: false,
      home: ShowHideDemo(),
    );
  }
}

class ShowHideDemo extends StatefulWidget {
  const ShowHideDemo({Key? key}) : super(key: key);

  @override
  // ignore: library_private_types_in_public_api
  _ShowHideDemoState createState() {
    return _ShowHideDemoState();
  }
}

class _ShowHideDemoState extends State {
  bool _isVisible = true;

  void showToast() {
    setState(() {
      _isVisible = !_isVisible;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('Flutter Show/Hide Widget Demo'),
      ),
      body: Padding(
        padding: const EdgeInsets.all(8.0),
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            Visibility(
              visible: _isVisible,
              child: Image.network(
                'https://images.unsplash.com/photo-1519125323398-675f0ddb6308?ixlib=rb-0.3.5&ixid=eyJhcHBfaWQiOjEyMDd9&s=94a1e718d89ca60a6337a6008341ca50&auto=format&fit=crop&w=1950&q=80',
                height: 300,
                fit: BoxFit.contain,
              ),
            ),
            const Text("Please Tab on the button to show/ hide image.",
                style: TextStyle(fontSize: 20)),
            const SizedBox(
              height: 35,
            ),
            ElevatedButton(
                style: ElevatedButton.styleFrom(
                  textStyle: const TextStyle(fontSize: 20),
                  minimumSize: const Size.fromHeight(50),
                ),
                onPressed: () {
                  setState(() {
                    _isVisible = !_isVisible;
                  });
                },
                child: const Text("Show/Hide")),
          ],
        ),
      ),
    );
  }
}

==> flutter_conscent_plugin-0.3.0.tar.gz: lib/BulletsFormat.dart <==
//



import 'package:flutter/material.dart';

void main() => runApp(const MyApp());

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);


  @override
  Widget build(BuildContext context) {
    return const MaterialApp(
      debugShowCheckedModeBanner: false,
      home:  ShowHideDemo(),
    );
  }
}

class ShowHideDemo extends StatefulWidget {
  const ShowHideDemo({Key? key}) : super(key: key);

  @override
  _ShowHideDemoState createState() {
    return _ShowHideDemoState();
  }
}

class _ShowHideDemoState extends State {
  bool _isVisible = true;

  void showToast() {
    setState(() {
      _isVisible = !_isVisible;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('Flutter Show/Hide Widget Demo'),
      ),
      body: Padding(
        padding: const EdgeInsets.all(8.0),
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            Visibility(
              visible: _isVisible,
              child: Image.network('https://images.unsplash.com/photo-1519125323398-675f0ddb6308?ixlib=rb-0.3.5&ixid=eyJhcHBfaWQiOjEyMDd9&s=94a1e718d89ca60a6337a6008341ca50&auto=format&fit=crop&w=1950&q=80',height: 300,
                fit: BoxFit.contain,
              ),

            ),
            const Text("Please Tab on the button to show/ hide image."
                ,style:  TextStyle(fontSize: 20)
            ),
            const SizedBox(height: 35,),
            ElevatedButton(
                style: ElevatedButton.styleFrom(
                  textStyle: const TextStyle(fontSize: 20),
                  minimumSize: const Size.fromHeight(50),
                ),
                onPressed: (){
                  setState(() {
                    _isVisible = !_isVisible;
                  });
                },
                child: const Text("Show/Hide")
            ),
          ],
        ),
      ),
    );
  }
}
